@@ -3,6 +3,8 @@ define ( 'FILE_WRITE_MODE', 0666 );
 define ( 'DB_GROUPNAME', '/var/webconfig/SAFe/application/db/safe.db' );
 define ( 'DB_TABLE', 'safe_object' );
 define ( 'OBJ_STATUS_MODIFIED', 'M' );
+define ( 'OBJ_STATUS_NEW', 'N' );
+define ( 'OBJ_STATUS_UP_TO_DATE', 'U' );
 define ( 'BASE_PATH', '/NSC/local/software' );
 function show_msg($msg = null) {
     if(!is_array($msg)){
