@@ -17,13 +17,14 @@
 
 # Adjust product info to license settings (try finding Brand and fallback to
 # Product)
-
 if [ "${1}" ] && [ -f $1 ]; then
 	product=`grep $1 -i -e 'brand' | cut -d= -f2`
 	if [ -z "$product" ]; then
 	  product=`grep $1 -i -e 'product' | cut -d= -f2`
 	fi
-else
+fi
+
+if [ ! "${product}" ]; then
   if [ -f /usr/local/sng/conf/brand.default ]; then
     product=`cat /usr/local/sng/conf/brand.default`
   else
