@@ -33,7 +33,7 @@ class Nsc_media_module_class extends Fs_media_module_class
      * @return 
      */
     public function api_create_profile($name, $data=null) {
-        $profile = new Nsc_media_profile_class($this->node() , $this->_obj_base_path, $name);
+        $profile = new Nsc_media_profile_class($this->node() , $this->_obj_base_path .'/profile', $name);
         $profile->configure();
         if($data) {
             $profile->set_data_values($data);
