@@ -34,7 +34,7 @@ class Nsc_sipsecmon_config_class extends Safe_configurable_object_class
     public function __construct($node, $parent_name, $name)
     {
         // Parent constructor to invoke unserialize if needed
-        parent::__construct($parent_name, $name, $node);
+        parent::__construct($parent_name, 'configuration', $node);
     }
     /**
      * @brief Return configuration description
@@ -70,7 +70,7 @@ class Nsc_sipsecmon_config_class extends Safe_configurable_object_class
         //active-record - Allows to run custom CI queries
         $log_level_enum = array(
             'debug' => 'Debug',
-            'info' => 'Information'
+            'info' => 'Info'
         );
         // Create object fields
         // Configurable objects
