@@ -453,7 +453,7 @@ class Safe_table_class
         $html .= '</ul>';
         return $html;
     }
-    public function generate()
+    public function generate(&$raw_data = null)
     {
         $html = "";
         $array_html = "";
@@ -543,6 +543,9 @@ class Safe_table_class
                 )
                 );
         }
+        if(null !== $raw_data){
+            $raw_data = $this->table->rows;
+        }
         $html.= $this->table->generate();
         if (empty($this->template['table_close']) && !empty($this->template['my_table_close'])) $html.= $this->template['my_table_close'];
         if (count($this->footer_button)) {
